==> ingdao-0.0.2.tar.gz: example/datasync/lib/ui/timesheet_save_screen.dart <==
import 'package:flutter/material.dart';
// import '../BLoC/location_query_bloc.dart';
// import '../DataLayer/location.dart';
// import '../BLoC/bloc_provider.dart';

import '../bloc/tanktimesheet_query_bloc.dart';
import '../datalayer/entity/tanktimesheet/tanktimesheetbean.dart';
import '../bloc/bloc_provider.dart';
import 'package:ingdao/dataflow/control/dfconverter.dart';

class TimesheetSaveScreen extends StatelessWidget {

  final TanktimesheetQueryBloc bloc;
  final TankTimesheetBean timesheet;

  const TimesheetSaveScreen({Key key, this.timesheet, this.bloc}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    // final locationqueryBloc = BlocProvider.of<LocationQueryBloc>(context);
    // print("${locationqueryBloc == null}");

    return Scaffold(
      appBar: AppBar(
        title: Text('Save Timesheet')
      ),
      body: TimesheetForm(timesheet: timesheet, bloc: bloc)
    );
  }

}

class TimesheetForm extends StatefulWidget {

final TanktimesheetQueryBloc bloc;
final TankTimesheetBean timesheet;

 const TimesheetForm({Key key, this.timesheet, this.bloc}) : super(key: key);

  @override
  TimesheetFormState createState() {
    return TimesheetFormState();
  }
}

class TimesheetFormState extends State<TimesheetForm> {

  TankTimesheetBean editTankTimesheet = TankTimesheetBean();
  final _formKey = GlobalKey<FormState>();

  @override
  Widget build(BuildContext context) {
    // Build a Form widget using the _formKey created above.
    return Form(
      key: _formKey,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.center,
        children: <Widget>[
          SizedBox(height: 8),
          TextFormField(
            decoration: InputDecoration(
              border: OutlineInputBorder(),
              labelText: 'Mark On'
            ),
            validator: (value) {
              if (value.isEmpty) {
                return 'Please specify mark on';
              }
              return null;
            },
            onSaved: (value) => editTankTimesheet.markOn = DfConverter.stringToDate(value),
          ),
          SizedBox(height: 8),
          TextFormField(
            decoration: InputDecoration(
              border: OutlineInputBorder(),
              labelText: 'Active'
            ),
            validator: (value) {
              if (value.isEmpty) {
                return 'Please specify active';
              }
              return null;
            },
            onSaved: (value) => editTankTimesheet.active = value == "1",
          ),

          Padding(
            padding: const EdgeInsets.symmetric(vertical: 16.0),
            child: ElevatedButton(
              onPressed: () {
                // Validate returns true if the form is valid, or false
                // otherwise.
                if (_formKey.currentState.validate()) {
                  _formKey.currentState.save();
                  // If the form is valid, display a Snackbar.
                  Scaffold.of(context)
                      .showSnackBar(SnackBar(content: Text('Processing Data')));
                  final tanktimesheetqueryBloc = widget.bloc; //BlocProvider.of<LocationQueryBloc>(context);
                  //print("newlocation title: ${newLocation.title} ");
                  widget.timesheet.markOn = editTankTimesheet.markOn;
                  widget.timesheet.active = editTankTimesheet.active;
                  tanktimesheetqueryBloc.saveTimesheet(widget.timesheet);
                  Navigator.of(context).pop();
                }
              },
              child: Text('Submit'),
            ),
          ),
        ],
      ),
    );
  }

}

==> ingdao-0.0.19.tar.gz: example/datasync/lib/ui/timesheet_save_screen.dart <==
import 'package:flutter/material.dart';
// import '../BLoC/location_query_bloc.dart';
// import '../DataLayer/location.dart';
// import '../BLoC/bloc_provider.dart';

import '../bloc/tanktimesheet_query_bloc.dart';
import '../datalayer/entity/tanktimesheet/tanktimesheet.dart';
import '../bloc/bloc_provider.dart';
import 'package:ingdao/dataflow/control/dfconverter.dart';

class TimesheetSaveScreen extends StatelessWidget {

  final TanktimesheetQueryBloc bloc;
  final TankTimesheet timesheet;

  const TimesheetSaveScreen({Key key, this.timesheet, this.bloc}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    // final locationqueryBloc = BlocProvider.of<LocationQueryBloc>(context);
    // print("${locationqueryBloc == null}");

    return Scaffold(
      appBar: AppBar(
        title: Text('Save Timesheet')
      ),
      body: TimesheetForm(timesheet: timesheet, bloc: bloc)
    );
  }

}

class TimesheetForm extends StatefulWidget {

final TanktimesheetQueryBloc bloc;
final TankTimesheet timesheet;

 const TimesheetForm({Key key, this.timesheet, this.bloc}) : super(key: key);

  @override
  TimesheetFormState createState() {
    return TimesheetFormState();
  }
}

class TimesheetFormState extends State<TimesheetForm> {

  TankTimesheet editTankTimesheet = TankTimesheet();
  final _formKey = GlobalKey<FormState>();

  @override
  Widget build(BuildContext context) {
    // Build a Form widget using the _formKey created above.
    return Form(
      key: _formKey,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.center,
        children: <Widget>[
          SizedBox(height: 8),
          TextFormField(
            decoration: InputDecoration(
              border: OutlineInputBorder(),
              labelText: 'Mark On'
            ),
            validator: (value) {
              if (value.isEmpty) {
                return 'Please specify mark on';
              }
              return null;
            },
            onSaved: (value) => editTankTimesheet.markOn = DfConverter.stringToDate(value),
          ),
          SizedBox(height: 8),
          TextFormField(
            decoration: InputDecoration(
              border: OutlineInputBorder(),
              labelText: 'Active'
            ),
            validator: (value) {
              if (value.isEmpty) {
                return 'Please specify active';
              }
              return null;
            },
            onSaved: (value) => editTankTimesheet.active = value == "1",
          ),

          Padding(
            padding: const EdgeInsets.symmetric(vertical: 16.0),
            child: ElevatedButton(
              onPressed: () {
                // Validate returns true if the form is valid, or false
                // otherwise.
                if (_formKey.currentState.validate()) {
                  _formKey.currentState.save();
                  // If the form is valid, display a Snackbar.
                  Scaffold.of(context)
                      .showSnackBar(SnackBar(content: Text('Processing Data')));
                  final tanktimesheetqueryBloc = widget.bloc; //BlocProvider.of<LocationQueryBloc>(context);
                  //print("newlocation title: ${newLocation.title} ");
                  widget.timesheet.markOn = editTankTimesheet.markOn;
                  widget.timesheet.active = editTankTimesheet.active;
                  tanktimesheetqueryBloc.saveTimesheet(widget.timesheet);
                  Navigator.of(context).pop();
                }
              },
              child: Text('Submit'),
            ),
          ),
        ],
      ),
    );
  }

}
